/*******************************************************************\

Module:

Author: Daniel Kroening, kroening@kroening.com

\*******************************************************************/

#ifndef CPROVER_STR_GETLINE_H
#define CPROVER_STR_GETLINE_H

#include <istream>
#include <string>

std::istream &str_getline(std::istream &in, std::string &dest);

#endif
